@@ -6,7 +6,8 @@ import click
 import requests
 from pycognito import Cognito
 
-from .vars import COGNITO_NETLOC_MAPPING, CREDSTORE_PATH, DEFAULT_PROFILE
+from .util import get_nomitall_config
+from .vars import CREDSTORE_PATH, DEFAULT_PROFILE
 
 
 class URL(click.ParamType):
@@ -15,17 +16,12 @@ class URL(click.ParamType):
     def convert(self, value, param, ctx):
         if not isinstance(value, tuple):
             parsed = urlparse(value)
-            if parsed.scheme not in ("http", "https"):
-                self.fail(
-                    f"invalid URL scheme {parsed.scheme}. Only HTTP URLs are allowed",
-                    param,
-                    ctx,
-                )
+            parsed = parsed._replace(scheme="https")
             if not parsed.netloc:
                 self.fail(
                     f"invalid URL {value}, must have a domain name", param, ctx,
                 )
-        return parsed
+            return parsed
 
 
 @click.group(
@@ -46,17 +42,17 @@ class URL(click.ParamType):
 @click.option("--username", prompt="NND Username")
 @click.option("--password", prompt=True, hide_input=True)
 def login(profile, nomitall_url, username, password):
-    base_url = nomitall_url.netloc
-
     if not CREDSTORE_PATH.exists():
         CREDSTORE_PATH.parent.mkdir(parents=True, exist_ok=True)
         creds = defaultdict(dict)
     else:
         with CREDSTORE_PATH.open() as f:
             creds = defaultdict(dict, json.load(f))
+
+    config = get_nomitall_config(nomitall_url.geturl())
     user = Cognito(
-        COGNITO_NETLOC_MAPPING[base_url]["userpool-id"],
-        COGNITO_NETLOC_MAPPING[base_url]["client-id"],
+        config["COGNITO_USERPOOL_ID"],
+        config["COGNITO_CLIENT_ID"],
         username=username,
         access_key="dummy_not_used",
         secret_key="dummy_not_used",
@@ -70,7 +66,7 @@ def login(profile, nomitall_url, username, password):
         raise click.Abort(f"Authorization failed {username}")
     except user.client.exceptions.PasswordResetRequiredException:
         raise click.Abort(f"Password reset required for {username}")
-    creds[profile][base_url] = {
+    creds[profile][config["COGNITO_USERPOOL_ID"]] = {
         "access-token": user.access_token,
         "refresh-token": user.refresh_token,
         "id-token": user.id_token,
@@ -94,7 +90,9 @@ def login(profile, nomitall_url, username, password):
         org_choice = click.prompt(
             "Choose default organization", value_proc=int, type=choices, default=0
         )
-        creds[profile][base_url]["default-org"] = choice_dict[org_choice]["uuid"]
+        creds[profile][config["COGNITO_USERPOOL_ID"]]["default-org"] = choice_dict[
+            org_choice
+        ]["uuid"]
         with CREDSTORE_PATH.open("w") as f:
             json.dump(creds, f, indent=4)
             CREDSTORE_PATH.chmod(0o600)
